# TH2 Act Component (Python)

## Overview
This repository is a library for custom gRPC act projects (check [th2-act-template-py](https://github.com/th2-net/th2-act-template-py) 
for the implementation template). Check the [Wiki](https://github.com/th2-net/th2-act-py/wiki) for instructions and examples.

The th2-act contains helper methods to create custom 
ActHadlers that implements custom gRPC API. Multiple ActHandlers allowed as well.

## Installation
To install `th2-act` package run the following command in the terminal:
```
pip install th2-act
```
